Installation
------------

PyDESeq2 can be installed from PyPI:

.. code-block:: bash

   pip install pydeseq2

We recommend installing within a conda environment:

.. code-block:: python

   conda env create -n pydeseq2
   conda activate pydeseq2
   pip install pydeseq2


If you're interested in contributing or want access to the development version,
please see the :doc:`contributing` section.
